<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" >
	<xsl:output version="1.0" method="xml" indent="yes" encoding="UTF-8"/>


	<xsl:variable name="VOUCHER_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="VOUCHER_DATE">
		<xsl:value-of select="concat(substring($VOUCHER_DATE_ORIG,1,4),substring($VOUCHER_DATE_ORIG,6,2),substring($VOUCHER_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="DELIVERY_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='DELIVERY_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="DELIVERY_DATE">
		<xsl:value-of select="concat(substring($DELIVERY_DATE_ORIG,1,4),substring($DELIVERY_DATE_ORIG,6,2),substring($DELIVERY_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="CURRENCY">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='CURRENCY']/@value"/>
	</xsl:variable>

	<xsl:template match="/DataDefinition">
		<rsm:CrossIndustryDocument xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:rsm="urn:ferd:CrossIndustryDocument:invoice:1p0" xmlns:ram="urn:un:unece:uncefact:data:standard:ReusableAggregateBusinessInformationEntity:12" xmlns:udt="urn:un:unece:uncefact:data:standard:UnqualifiedDataType:15">
			<rsm:SpecifiedExchangedDocumentContext>
				<ram:TestIndicator>
					<udt:Indicator>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemChoice[@itemId='TEST_INDICATOR']/@value"/>
					</udt:Indicator>
				</ram:TestIndicator>
				<!-- Im Echtbetrieb muss der TestIndicator entweder vollständig entfallen oder auf false stehen. -->
				<ram:GuidelineSpecifiedDocumentContextParameter>
					<ram:ID>urn:ferd:CrossIndustryDocument:invoice:1p0:basic</ram:ID>
				</ram:GuidelineSpecifiedDocumentContextParameter>
			</rsm:SpecifiedExchangedDocumentContext>
			<rsm:HeaderExchangedDocument>
				<ram:ID>
					<xsl:value-of select="DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_ID']/@value"/>
				</ram:ID>
				<ram:Name>RECHNUNG</ram:Name>
				<ram:TypeCode>380</ram:TypeCode>
				<ram:IssueDateTime>
					<udt:DateTimeString format="102">
						<xsl:value-of select="$VOUCHER_DATE"/>
					</udt:DateTimeString>
				</ram:IssueDateTime>
			</rsm:HeaderExchangedDocument>
			<rsm:SpecifiedSupplyChainTradeTransaction>
				<ram:ApplicableSupplyChainTradeAgreement>
					<ram:SellerTradeParty>
						<ram:Name>
							<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
						</ram:Name>
						<ram:PostalTradeAddress>
							<ram:PostcodeCode>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_ZIP']/@value"/>
							</ram:PostcodeCode>
							<ram:LineOne>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE']/@value"/>
							</ram:LineOne>
							<ram:CityName>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_CITY']/@value"/>
							</ram:CityName>
							<ram:CountryID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemChoice[@itemId='SELLER_ADDRESS_COUNTRY']/@value"/>
							</ram:CountryID>
						</ram:PostalTradeAddress>
						<ram:SpecifiedTaxRegistration>
							<ram:ID schemeID="VA">
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_ID']/@value"/>
							</ram:ID>
						</ram:SpecifiedTaxRegistration>
					</ram:SellerTradeParty>
					<ram:BuyerTradeParty>
						<ram:Name>
							<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_NAME']/@value"/>
						</ram:Name>
						<ram:PostalTradeAddress>
							<ram:PostcodeCode>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_ZIP']/@value"/>
							</ram:PostcodeCode>
							<ram:LineOne>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE']/@value"/>
							</ram:LineOne>
							<ram:CityName>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_CITY']/@value"/>
							</ram:CityName>
							<ram:CountryID>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemChoice[@itemId='BUYER_ADDRESS_COUNTRY']/@value"/>
							</ram:CountryID>
						</ram:PostalTradeAddress>
					</ram:BuyerTradeParty>
				</ram:ApplicableSupplyChainTradeAgreement>
				<ram:ApplicableSupplyChainTradeDelivery>
					<ram:ActualDeliverySupplyChainEvent>
						<ram:OccurrenceDateTime>
							<udt:DateTimeString format="102">
								<xsl:value-of select="$DELIVERY_DATE"/>
							</udt:DateTimeString>
						</ram:OccurrenceDateTime>
					</ram:ActualDeliverySupplyChainEvent>
				</ram:ApplicableSupplyChainTradeDelivery>
				<ram:ApplicableSupplyChainTradeSettlement>
					<ram:PaymentReference>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PAYMENT_REFERENCE']/@value"/>
					</ram:PaymentReference>
					<ram:InvoiceCurrencyCode>
						<xsl:value-of select="$CURRENCY"/>
					</ram:InvoiceCurrencyCode>
					<ram:SpecifiedTradeSettlementPaymentMeans>
						<ram:PayeePartyCreditorFinancialAccount>
							<ram:IBANID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_IBAN']/@value"/>
							</ram:IBANID>
						</ram:PayeePartyCreditorFinancialAccount>
						<ram:PayeeSpecifiedCreditorFinancialInstitution>
							<ram:BICID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_BIC']/@value"/>
							</ram:BICID>
						</ram:PayeeSpecifiedCreditorFinancialInstitution>
					</ram:SpecifiedTradeSettlementPaymentMeans>
					<ram:ApplicableTradeTax>
						<ram:CalculatedAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='TAX_AMOUNT']/@value, '0.00')"/>
						</ram:CalculatedAmount>
						<ram:TypeCode>VAT</ram:TypeCode>
						<ram:BasisAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='NET_AMOUNT']/@value, '0.00')"/>
						</ram:BasisAmount>
						<ram:ApplicablePercent>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='TAX_PERCENT']/@value, '0.00')"/>
						</ram:ApplicablePercent>
					</ram:ApplicableTradeTax>
					<ram:SpecifiedTradeSettlementMonetarySummation>
						<ram:LineTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='LINE_TOTAL_AMOUNT']/@value, '0.00')"/>
						</ram:LineTotalAmount>
						<ram:ChargeTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='CHARGE_AMOUNT']/@value, '0.00')"/>
						</ram:ChargeTotalAmount>
						<ram:AllowanceTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='ALLOWANCE_AMOUNT']/@value, '0.00')"/>
						</ram:AllowanceTotalAmount>
						<ram:TaxBasisTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='NET_AMOUNT']/@value, '0.00')"/>
						</ram:TaxBasisTotalAmount>
						<ram:TaxTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='TAX_AMOUNT']/@value, '0.00')"/>
						</ram:TaxTotalAmount>
						<ram:GrandTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='GROSS_AMOUNT']/@value, '0.00')"/>
						</ram:GrandTotalAmount>
					</ram:SpecifiedTradeSettlementMonetarySummation>
				</ram:ApplicableSupplyChainTradeSettlement>

				<!--Items -->

				<!--xsl:for-each select="DataItemCollection[@itemId='ITEM_DETAILS']/DataItem[DataItemString[@itemId='ITEM_NAME' and @value!=''] ]"-->
				<xsl:for-each select="DataItemCollection[@itemId='ITEM_DETAILS']/DataItem">
					<ram:IncludedSupplyChainTradeLineItem>
						<ram:AssociatedDocumentLineDocument>
							<!--ram:LineID>
							<xsl:value-of select="DataItemNumeric[@itemId='ITEM_LINE_ID']/@value"/>
						</ram:LineID-->
						</ram:AssociatedDocumentLineDocument>
						<ram:SpecifiedSupplyChainTradeDelivery>
							<ram:BilledQuantity>
								<xsl:attribute name="unitCode">
									C62<!--xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/-->
								</xsl:attribute>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_QUANTITY']/@value, '0.0000')"/>
							</ram:BilledQuantity>
						</ram:SpecifiedSupplyChainTradeDelivery>
						<ram:SpecifiedSupplyChainTradeSettlement>
							<!--ram:SpecifiedTradeSettlementMonetarySummation>
							<ram:LineTotalAmount>
								<xsl:attribute name="currencyID"><xsl:value-of select="$CURRENCY"/></xsl:attribute>
								<xsl:value-of select="DataItemNumeric[@itemId='ITEM_TOTAL_AMOUNT']/@value"/>
							</ram:LineTotalAmount>
						</ram:SpecifiedTradeSettlementMonetarySummation-->
						</ram:SpecifiedSupplyChainTradeSettlement>
						<ram:SpecifiedTradeProduct>
							<!--ram:SellerAssignedID><xsl:value-of select="DataItemString[@itemId='ITEM_SELLER_ID']/@value"/></ram:SellerAssignedID-->
							<ram:Name>
								<xsl:value-of select="DataItemString[@itemId='ITEM_NAME']/@value"/>
							</ram:Name>
						</ram:SpecifiedTradeProduct>
					</ram:IncludedSupplyChainTradeLineItem>
				</xsl:for-each>
			</rsm:SpecifiedSupplyChainTradeTransaction>
		</rsm:CrossIndustryDocument>
	</xsl:template>
</xsl:stylesheet>