<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" >
	<xsl:output version="1.0" method="xml" indent="yes" encoding="UTF-8"/>


	<xsl:variable name="VOUCHER_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="VOUCHER_DATE">
		<xsl:value-of select="concat(substring($VOUCHER_DATE_ORIG,1,4),substring($VOUCHER_DATE_ORIG,6,2),substring($VOUCHER_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="DELIVERY_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='DELIVERY_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="DELIVERY_DATE">
		<xsl:value-of select="concat(substring($DELIVERY_DATE_ORIG,1,4),substring($DELIVERY_DATE_ORIG,6,2),substring($DELIVERY_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="PAYMENT_TERMS_DUE_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='PAYMENT_TERMS_DUE_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="PAYMENT_TERMS_DUE_DATE">
		<xsl:value-of select="concat(substring($PAYMENT_TERMS_DUE_DATE_ORIG,1,4),substring($PAYMENT_TERMS_DUE_DATE_ORIG,6,2),substring($PAYMENT_TERMS_DUE_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="CURRENCY">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='CURRENCY']/@value"/>
	</xsl:variable>

	<xsl:template match="/DataDefinition">
		<rsm:CrossIndustryInvoice
		  xmlns:rsm="urn:un:unece:uncefact:data:standard:CrossIndustryInvoice:100"
		  xmlns:ram="urn:un:unece:uncefact:data:standard:ReusableAggregateBusinessInformationEntity:100"
		  xmlns:udt="urn:un:unece:uncefact:data:standard:UnqualifiedDataType:100"
    >
			<rsm:ExchangedDocumentContext>
				<ram:TestIndicator>
					<udt:Indicator>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemChoice[@itemId='TEST_INDICATOR']/@value"/>
					</udt:Indicator>
				</ram:TestIndicator>

				<ram:GuidelineSpecifiedDocumentContextParameter>
					<ram:ID>urn:cen.eu:en16931:2017</ram:ID>
				</ram:GuidelineSpecifiedDocumentContextParameter>
			</rsm:ExchangedDocumentContext>

			<rsm:ExchangedDocument>
				<ram:ID>
					<xsl:value-of select="DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_ID']/@value"/>
				</ram:ID>
				<ram:TypeCode>
					<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemChoice[@itemId='DOCUMENT_TYPE']/@value"/>
				</ram:TypeCode>
				<ram:IssueDateTime>
					<udt:DateTimeString format="102">
						<xsl:value-of select="$VOUCHER_DATE"/>
					</udt:DateTimeString>
				</ram:IssueDateTime>
			</rsm:ExchangedDocument>

			<rsm:SupplyChainTradeTransaction>

				<!--Items -->

				<xsl:for-each select="DataItemCollection[@itemId='ITEM_DETAILS']/DataItem">
					<ram:IncludedSupplyChainTradeLineItem>
						<ram:AssociatedDocumentLineDocument>
							<ram:LineID>
								<xsl:value-of select="DataItemString[@itemId='ITEM_LINE_ID']/@value"/>
							</ram:LineID>
						</ram:AssociatedDocumentLineDocument>

						<ram:SpecifiedTradeProduct>
							<!--ram:GlobalID schemeID="0160">...</ram:GlobalID-->
							<ram:SellerAssignedID>
								<xsl:value-of select="DataItemString[@itemId='ITEM_SELLER_ID']/@value"/>
							</ram:SellerAssignedID>
							<ram:BuyerAssignedID/>
							<ram:Name>
								<xsl:value-of select="DataItemString[@itemId='ITEM_NAME']/@value"/>
							</ram:Name>
							<!--ram:Description/>...</ram:Description-->
						</ram:SpecifiedTradeProduct>

						<ram:SpecifiedLineTradeAgreement>
							<ram:GrossPriceProductTradePrice>
								<ram:ChargeAmount>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_GROSS_PRICE']/@value, '0.0000')"/>
								</ram:ChargeAmount>
								<xsl:if test="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000') != 'NaN'">
									<ram:BasisQuantity>
										<xsl:attribute name="unitCode">
											<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
										</xsl:attribute>
										<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000')"/>
									</ram:BasisQuantity>
								</xsl:if>
							</ram:GrossPriceProductTradePrice>
							<ram:NetPriceProductTradePrice>
								<ram:ChargeAmount>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_GROSS_PRICE']/@value, '0.0000')"/>
								</ram:ChargeAmount>
								<xsl:if test="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000') != 'NaN'">
									<ram:BasisQuantity>
										<xsl:attribute name="unitCode">
											<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
										</xsl:attribute>
										<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000')"/>
									</ram:BasisQuantity>
								</xsl:if>
							</ram:NetPriceProductTradePrice>
						</ram:SpecifiedLineTradeAgreement>

						<ram:SpecifiedLineTradeDelivery>
							<ram:BilledQuantity>
								<xsl:attribute name="unitCode">
									<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
								</xsl:attribute>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_QUANTITY']/@value, '0.0000')"/>
							</ram:BilledQuantity>
						</ram:SpecifiedLineTradeDelivery>

						<ram:SpecifiedLineTradeSettlement>
							<ram:ApplicableTradeTax>
								<ram:TypeCode>VAT</ram:TypeCode>
								<ram:CategoryCode>
									<xsl:value-of select="DataItemChoice[@itemId='ITEM_VAT_CATEGORY']/@value"/>
								</ram:CategoryCode>
								<ram:RateApplicablePercent>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_VAT_PERCENT']/@value, '0.00')"/>
								</ram:RateApplicablePercent>
							</ram:ApplicableTradeTax>
							<ram:SpecifiedTradeSettlementLineMonetarySummation>
								<ram:LineTotalAmount>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_TOTAL_AMOUNT']/@value, '0.00')"/>
								</ram:LineTotalAmount>
							</ram:SpecifiedTradeSettlementLineMonetarySummation>
						</ram:SpecifiedLineTradeSettlement>
					</ram:IncludedSupplyChainTradeLineItem>
				</xsl:for-each>

				<ram:ApplicableHeaderTradeAgreement>
					<ram:SellerTradeParty>
						<ram:Name>
							<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
						</ram:Name>
						<!--ram:GlobalID schemeID="0088">...</ram:GlobalID-->
						<ram:PostalTradeAddress>
							<ram:PostcodeCode>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_ZIP']/@value"/>
							</ram:PostcodeCode>
							<ram:LineOne>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE']/@value"/>
							</ram:LineOne>
							<ram:CityName>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_CITY']/@value"/>
							</ram:CityName>
							<ram:CountryID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemChoice[@itemId='SELLER_ADDRESS_COUNTRY']/@value"/>
							</ram:CountryID>
						</ram:PostalTradeAddress>
						<ram:SpecifiedTaxRegistration>
							<ram:ID schemeID="VA">
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_ID']/@value"/>
							</ram:ID>
						</ram:SpecifiedTaxRegistration>
					</ram:SellerTradeParty>
					<ram:BuyerTradeParty>
						<ram:Name>
							<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_NAME']/@value"/>
						</ram:Name>
						<ram:PostalTradeAddress>
							<ram:PostcodeCode>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_ZIP']/@value"/>
							</ram:PostcodeCode>
							<ram:LineOne>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE']/@value"/>
							</ram:LineOne>
							<ram:CityName>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_CITY']/@value"/>
							</ram:CityName>
							<ram:CountryID>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemChoice[@itemId='BUYER_ADDRESS_COUNTRY']/@value"/>
							</ram:CountryID>
						</ram:PostalTradeAddress>
					</ram:BuyerTradeParty>
					<ram:BuyerOrderReferencedDocument>
						<ram:IssuerAssignedID>
							<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='BUYER_ORDER_ID']/@value"/>
						</ram:IssuerAssignedID>
					</ram:BuyerOrderReferencedDocument>
				</ram:ApplicableHeaderTradeAgreement>

				<ram:ApplicableHeaderTradeDelivery>
					<ram:ActualDeliverySupplyChainEvent>
						<ram:OccurrenceDateTime>
							<udt:DateTimeString format="102">
								<xsl:value-of select="$DELIVERY_DATE"/>
							</udt:DateTimeString>
						</ram:OccurrenceDateTime>
					</ram:ActualDeliverySupplyChainEvent>
				</ram:ApplicableHeaderTradeDelivery>

				<ram:ApplicableHeaderTradeSettlement>
					<ram:PaymentReference>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PAYMENT_REFERENCE']/@value"/>
					</ram:PaymentReference>
					<ram:InvoiceCurrencyCode>
						<xsl:value-of select="$CURRENCY"/>
					</ram:InvoiceCurrencyCode>
					<ram:SpecifiedTradeSettlementPaymentMeans>
						<ram:TypeCode>42</ram:TypeCode>
						<!--Note: The entries from the UNTDID 4461 code list shall be used. Distinction should be made between SEPA- and non- SEPA payments and between credit payments, direct debits, card payments and other instruments.-->
						<ram:PayeePartyCreditorFinancialAccount>
							<ram:IBANID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_IBAN']/@value"/>
							</ram:IBANID>
							<!--ram:AccountName>
                <xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
              </ram:AccountName-->
						</ram:PayeePartyCreditorFinancialAccount>
						<ram:PayeeSpecifiedCreditorFinancialInstitution>
							<ram:BICID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_BIC']/@value"/>
							</ram:BICID>
						</ram:PayeeSpecifiedCreditorFinancialInstitution>
					</ram:SpecifiedTradeSettlementPaymentMeans>

					<!-- VAT / TAX -->

					<xsl:for-each select="DataItemCollection[@itemId='VAT']/DataItem">
						<ram:ApplicableTradeTax>
							<ram:CalculatedAmount>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='VAT_AMOUNT']/@value, '0.00')"/>
							</ram:CalculatedAmount>
							<ram:TypeCode>VAT</ram:TypeCode>
							<ram:BasisAmount>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='BASIS_AMOUNT']/@value, '0.00')"/>
							</ram:BasisAmount>
							<ram:CategoryCode>
								<xsl:value-of select="DataItemChoice[@itemId='VAT_CATEGORY']/@value"/>
							</ram:CategoryCode>
							<ram:RateApplicablePercent>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='VAT_PERCENT']/@value, '0.00')"/>
							</ram:RateApplicablePercent>
						</ram:ApplicableTradeTax>
					</xsl:for-each>

					<ram:SpecifiedTradePaymentTerms>
						<ram:Description>
							<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PAYMENT_TERMS_DESCRIPTION']/@value"/>
						</ram:Description>
						<ram:DueDateDateTime>
							<udt:DateTimeString format="102">
								<xsl:value-of select="$PAYMENT_TERMS_DUE_DATE"/>
							</udt:DateTimeString>
						</ram:DueDateDateTime>
					</ram:SpecifiedTradePaymentTerms>

					<ram:SpecifiedTradeSettlementHeaderMonetarySummation>
						<ram:LineTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='NET_AMOUNT']/@value, '0.00')"/>
						</ram:LineTotalAmount>
						<ram:ChargeTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='CHARGE_AMOUNT']/@value, '0.00')"/>
						</ram:ChargeTotalAmount>
						<ram:AllowanceTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='ALLOWANCE_AMOUNT']/@value, '0.00')"/>
						</ram:AllowanceTotalAmount>
						<ram:TaxBasisTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='NET_AMOUNT']/@value, '0.00')"/>
						</ram:TaxBasisTotalAmount>
						<ram:TaxTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='TAX_AMOUNT']/@value, '0.00')"/>
						</ram:TaxTotalAmount>
						<ram:GrandTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='GROSS_AMOUNT']/@value, '0.00')"/>
						</ram:GrandTotalAmount>
						<ram:DuePayableAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='HEADER']/DataItemNumeric[@itemId='DUE_PAYABLE_AMOUNT']/@value, '0.00')"/>
						</ram:DuePayableAmount>
					</ram:SpecifiedTradeSettlementHeaderMonetarySummation>
				</ram:ApplicableHeaderTradeSettlement>

			</rsm:SupplyChainTradeTransaction>
		</rsm:CrossIndustryInvoice>
	</xsl:template>
</xsl:stylesheet>